# Shakeabuse

A simple command line app to display a random shakespearean abuse on the console.

## Installation

```
pip install shakeabuse
```
or, since you're probably using `python3`
```
pip3 install shakeabuse
```

## Usage

```
$ shkabuse
Thou paunchy fly-bitten giglet!
$ shkabuse
Thou vain ill-nurtured bugbear!
$ shkabuse
Thou artless hasty-witted flap-dragon!
$ shkabuse
Methink'st thou art a general offence and every man should beat thee.
```

---
Idea stolen from my friend [Shuvojit Sarkar](https://github.com/shuvojit-tps). He once wrote an android app that did the same thing.
